@@ -47,6 +47,9 @@ _db_mysql_update_query_type = None
 _db_mysql_delete_query_type = None
 _db_table_type = None
 _db_relationship_type = None
+# ================================================== dir_utils - types
+_dir_type = None
+
 
 
 
@@ -124,6 +127,10 @@ if TYPE_CHECKING:
     _element_type = _TypeVar('_element_type', bound=_etree.Element)
 
 
+    import colemen_utilities.directory_utils.dir as _dir
+    _dir_type = _TypeVar('_dir_type', bound=_dir.Directory)
+
+
 
     import inflect as _inflect
     _inflect_engine_type = _TypeVar('_inflect_engine_type', bound=_inflect.engine)
