@@ -109,7 +109,7 @@ def find_list_diff(list_one, list_two):
     '''
     return [x for x in list_one if x not in list_two]
 
-def force_list(value)->list:
+def force_list(value,allow_nulls=True)->list:
     '''
         Confirm that the value is a list, if not wrap it in a list.
 
@@ -120,6 +120,9 @@ def force_list(value)->list:
         `value` {any}
             The value to test.
 
+        [`allow_nulls`=True] {bool}
+            If False and the value is null, the list will be empty.
+
         Return {list}
         ----------------------
         The value as a list
@@ -133,7 +136,8 @@ def force_list(value)->list:
         `method_name`: force_list
         * @xxx [06-03-2022 09:14:52]: documentation for force_list
     '''
-
+    if value is None and allow_nulls is False:
+        return []
 
     if isinstance(value,(tuple)) is True:
         return list(value)
